@@ -13,12 +13,11 @@ from .position import Position, PositionCond, PriceSet
 from loguru import logger
 from shioaji.constant import (
     Action,
-    TFTStockPriceType,
-    TFTOrderType,
+    StockPriceType,
+    OrderType,
     QuoteVersion,
     Exchange,
     OrderState,
-    StockFirstSell,
 )
 
 
@@ -160,10 +159,8 @@ class SJTrader:
                                 quantity=abs(q),
                                 action=Action.Buy if pos > 0 else Action.Sell,
                                 price_type=price_set.price_type,
-                                order_type=TFTOrderType.ROD,
-                                first_sell=StockFirstSell.No
-                                if pos > 0
-                                else StockFirstSell.Yes,
+                                order_type=OrderType.ROD,
+                                daytrade_short= False if pos > 0 else True,
                                 custom_field=self.name,
                             ),
                             timeout=0,
@@ -191,7 +188,10 @@ class SJTrader:
             api = self.api
         # 8:55 - 8:59:55
         if tick.simtrade:
-            if position.cond.quantity < 0 and float(tick.close) == position.contract.limit_up:
+            if (
+                position.cond.quantity < 0
+                and float(tick.close) == position.contract.limit_up
+            ):
                 with position.lock:
                     position.status.cancel_preorder = True
                 for trade in self.positions[tick.code].entry_trades:
@@ -222,17 +222,15 @@ class SJTrader:
                 ):  # TODO check min or max
                     trade = api.place_order(
                         contract=position.contract,
-                        order=sj.order.TFTStockOrder(
+                        order=sj.order.StockOrder(
                             price=0,
                             quantity=abs(position.cond.quantity),
                             action=Action.Buy
                             if position.cond.quantity > 0
                             else Action.Sell,
-                            price_type=TFTStockPriceType.MKT,
-                            order_type=TFTOrderType.ROD,
-                            first_sell=StockFirstSell.No
-                            if position.cond.quantity > 0
-                            else StockFirstSell.Yes,
+                            price_type=StockPriceType.MKT,
+                            order_type=OrderType.ROD,
+                            daytrade_short=False if position.cond.quantity > 0 else True,
                             custom_field=self.name,
                         ),
                         timeout=0,
@@ -252,8 +250,8 @@ class SJTrader:
 
     def stop_profit(self, position: Position, tick: sj.TickSTKv1):
         if not tick.simtrade:
-            cover_quantity = (
-                position.status.open_quantity + position.status.cover_order_quantity
+            cover_quantity = position.status.open_quantity + (
+                position.status.cover_order_quantity - position.status.cover_quantity
             )
             if cover_quantity == 0:
                 return
@@ -275,8 +273,8 @@ class SJTrader:
 
     def stop_loss(self, position: Position, tick: sj.TickSTKv1):
         if not tick.simtrade:
-            cover_quantity = (
-                position.status.open_quantity + position.status.cover_order_quantity
+            cover_quantity = position.status.open_quantity + (
+                position.status.cover_order_quantity - position.status.cover_quantity
             )
             if cover_quantity == 0:
                 return
@@ -303,8 +301,8 @@ class SJTrader:
             api = self.simulation_api
         else:
             api = self.api
-        cover_quantity = (
-            position.status.open_quantity + position.status.cover_order_quantity
+        cover_quantity = position.status.open_quantity + (
+            position.status.cover_order_quantity - position.status.cover_quantity
         )
         if not price_sets:
             price_sets = self.stratagy.cover_price_set(
@@ -321,14 +319,14 @@ class SJTrader:
                 for q in quantity_s:
                     trade = api.place_order(
                         contract=position.contract,
-                        order=sj.order.TFTStockOrder(
+                        order=sj.order.StockOrder(
                             price=price_set.price,
                             quantity=abs(q),
                             action=Action.Buy
                             if position.cond.quantity < 0
                             else Action.Sell,
                             price_type=price_set.price_type,
-                            order_type=TFTOrderType.ROD,
+                            order_type=OrderType.ROD,
                             custom_field=self.name,
                         ),
                         timeout=0,
@@ -391,11 +389,11 @@ class SJTrader:
 
     def order_deal_handler(self, order_stats: OrderState, msg: Dict):
         if (
-            order_stats == OrderState.TFTOrder
+            order_stats == OrderState.StockOrder
             and msg["order"]["custom_field"] == self.name
         ):
             self.order_handler(msg, self.positions[msg["contract"]["code"]])
-        elif order_stats == OrderState.TFTDeal and msg["custom_field"] == self.name:
+        elif order_stats == OrderState.StockDeal and msg["custom_field"] == self.name:
             self.deal_handler(msg, self.positions[msg["code"]])
 
     def order_handler(self, msg: Dict, position: Position):
